@@ -43,7 +43,7 @@ override('prepare', sub {
     return 1;
 });
 
-override('pack', sub {
+override('finalize', sub {
     my $self = shift();
 
     my $clicker = $self->clicker;
